@@ -1,4 +1,4 @@
-from dagster.core.utils import check_dagster_package_version
+from dagster._core.utils import check_dagster_package_version
 
 from .dagster_job_factory import make_dagster_job_from_airflow_dag
 from .dagster_pipeline_factory import (
@@ -8,6 +8,7 @@ from .dagster_pipeline_factory import (
     make_dagster_repo_from_airflow_example_dags,
 )
 from .factory import make_airflow_dag, make_airflow_dag_containerized, make_airflow_dag_for_operator
+from .operators.airflow_operator_to_op import airflow_operator_to_op
 from .version import __version__
 
 check_dagster_package_version("dagster-airflow", __version__)
@@ -20,4 +21,5 @@ __all__ = [
     "make_dagster_repo_from_airflow_dags_path",
     "make_dagster_repo_from_airflow_dag_bag",
     "make_dagster_job_from_airflow_dag",
+    "airflow_operator_to_op",
 ]
